Module: Solace::SquadsSmartAccounts
- Defined in:
- lib/solace/squads_smart_accounts.rb,
lib/solace/squads_smart_accounts/version.rb,
lib/solace/squads_smart_accounts/constants.rb,
lib/solace/squads_smart_accounts/vault_index.rb,
lib/solace/squads_smart_accounts/types/period.rb,
lib/solace/squads_smart_accounts/types/proposal.rb,
lib/solace/squads_smart_accounts/types/settings.rb,
lib/solace/squads_smart_accounts/types/permissions.rb,
lib/solace/squads_smart_accounts/types/transaction.rb,
lib/solace/squads_smart_accounts/types/program_config.rb,
lib/solace/squads_smart_accounts/types/spending_limit.rb,
lib/solace/squads_smart_accounts/types/settings_action.rb,
lib/solace/squads_smart_accounts/types/transaction_message.rb,
lib/solace/squads_smart_accounts/types/settings_transaction.rb,
lib/solace/squads_smart_accounts/types/smart_account_signer.rb,
lib/solace/squads_smart_accounts/types/smart_account_identity.rb,
lib/solace/squads_smart_accounts/instructions/cancel_proposal_instruction.rb,
lib/solace/squads_smart_accounts/instructions/create_proposal_instruction.rb,
lib/solace/squads_smart_accounts/instructions/reject_proposal_instruction.rb,
lib/solace/squads_smart_accounts/instructions/approve_proposal_instruction.rb,
lib/solace/squads_smart_accounts/instructions/activate_proposal_instruction.rb,
lib/solace/squads_smart_accounts/instructions/close_transaction_instruction.rb,
lib/solace/squads_smart_accounts/instructions/create_transaction_instruction.rb,
lib/solace/squads_smart_accounts/instructions/use_spending_limit_instruction.rb,
lib/solace/squads_smart_accounts/instructions/execute_transaction_instruction.rb,
lib/solace/squads_smart_accounts/instructions/create_smart_account_instruction.rb,
lib/solace/squads_smart_accounts/instructions/add_signer_as_authority_instruction.rb,
lib/solace/squads_smart_accounts/instructions/execute_transaction_sync_instruction.rb,
lib/solace/squads_smart_accounts/instructions/close_settings_transaction_instruction.rb,
lib/solace/squads_smart_accounts/instructions/remove_signer_as_authority_instruction.rb,
lib/solace/squads_smart_accounts/instructions/set_time_lock_as_authority_instruction.rb,
lib/solace/squads_smart_accounts/instructions/create_settings_transaction_instruction.rb,
lib/solace/squads_smart_accounts/instructions/execute_settings_transaction_instruction.rb,
lib/solace/squads_smart_accounts/instructions/change_threshold_as_authority_instruction.rb,
lib/solace/squads_smart_accounts/instructions/add_spending_limit_as_authority_instruction.rb,
lib/solace/squads_smart_accounts/instructions/execute_settings_transaction_sync_instruction.rb,
lib/solace/squads_smart_accounts/instructions/remove_spending_limit_as_authority_instruction.rb,
lib/solace/squads_smart_accounts/instructions/set_new_settings_authority_as_authority_instruction.rb
Defined Under Namespace
Modules: Instructions, Period, Permissions, VaultIndex Classes: Error, ProgramConfig, Proposal, Settings, SettingsAction, SettingsTransaction, SmartAccountIdentity, SmartAccountSigner, SpendingLimit, Transaction, TransactionMessage
Constant Summary collapse
- VERSION =
'0.1.0'- PROGRAM_ID =
Canonical on-chain program ID for the Squads Smart Account program.
'SMRTzfY6DfH5ik3TKiyLFfXexV8uSG3d2UksSCYdunG'- MAINNET_PROGRAM_ID =
Cluster-scoped aliases — provided for consistency; both resolve to the same program ID since Squads deploys identically across clusters.
PROGRAM_ID- DEVNET_PROGRAM_ID =
PROGRAM_ID- PROGRAM_CONFIG_ADDRESS =
PDA for the global program config account, derived from seeds [“smart_account”, “program_config”]. Holds the treasury address and smart account creation fee.
'GmY9kVi3FhrCUn2MJkzzpE6C5618YoHuGsgqHU78cKus'- DEFAULT_PUBKEY =
Base58 of Pubkey::default() (32 zero bytes). The program stores this as the settings_authority of autonomous smart accounts; handing the authority to this key permanently renounces control (nobody can sign as it). It also marks SOL (as opposed to an SPL mint) in spending limits.
'11111111111111111111111111111111'- I64_MAX =
Maximum i64 value. The program uses this as the expiration of non-expiring spending limits.
9_223_372_036_854_775_807