Class: Solace::SquadsSmartAccounts::SmartAccountSigner
- Inherits:
-
Data
- Object
- Data
- Solace::SquadsSmartAccounts::SmartAccountSigner
- Defined in:
- lib/solace/squads_smart_accounts/types/smart_account_signer.rb
Overview
Immutable value object representing a signer entry on a smart account.
Instance Attribute Summary collapse
-
#permission ⇒ Object
readonly
Returns the value of attribute permission.
-
#pubkey ⇒ Object
readonly
Returns the value of attribute pubkey.
Instance Method Summary collapse
-
#initialize(pubkey:, permission:) ⇒ SmartAccountSigner
constructor
Normalizes the pubkey to its base58 string so callers can pass a String, Keypair, or PublicKey interchangeably.
Constructor Details
#initialize(pubkey:, permission:) ⇒ SmartAccountSigner
Normalizes the pubkey to its base58 string so callers can pass a String, Keypair, or PublicKey interchangeably.
21 22 23 |
# File 'lib/solace/squads_smart_accounts/types/smart_account_signer.rb', line 21 def initialize(pubkey:, permission:) super(pubkey: pubkey.to_s, permission:) end |
Instance Attribute Details
#permission ⇒ Object (readonly)
Returns the value of attribute permission
12 13 14 |
# File 'lib/solace/squads_smart_accounts/types/smart_account_signer.rb', line 12 def @permission end |
#pubkey ⇒ Object (readonly)
Returns the value of attribute pubkey
12 13 14 |
# File 'lib/solace/squads_smart_accounts/types/smart_account_signer.rb', line 12 def pubkey @pubkey end |